// SPDX-FileCopyrightText: Copyright 2015-2025 go-swagger maintainers
// SPDX-License-Identifier: Apache-2.0

// Package stdlib exposes a JSON adapter built on top
// of the standard library.
//
// Since this package doesn't add any specific dependency, it does not
// ship as an independent go module.
package stdlib
