// SPDX-FileCopyrightText: Copyright 2015-2025 go-swagger maintainers
// SPDX-License-Identifier: Apache-2.0

// Package fixtures exposes a test [Harness] utility
// to test JSON and YAML transformations.
package fixtures
