// SPDX-FileCopyrightText: Copyright 2015-2025 go-swagger maintainers
// SPDX-License-Identifier: Apache-2.0

// Package json implements an [ifaces.Adapter] using [github.com/mailru/easyjson].
package json

import (
	_ "github.com/go-openapi/swag/jsonutils/adapters/ifaces" // for documentation purpose
)
