// SPDX-FileCopyrightText: Copyright 2015-2025 go-swagger maintainers
// SPDX-License-Identifier: Apache-2.0

// Package testintegration contains tests
// that stitch together different JSON adapters.
package testintegration
